<?php

/**
 * Cryptor/yform class
 *
 * @author Marshall
 */
class cryptor_yform {
    
    protected static $addon = null;

    /**
     * Handles extensionpoint
     * @param <obj> $ep
     */
    public static function handleExtensionpoint(rex_extension_point $ep) {
        if ($ep->getSubject() instanceof Exception) {
            return;
        }

        // Get the config for this table name
        $config = self::getConfigForTable($ep->getParam('table'));
        if (!is_array($config)) {
            return;
        }
        
        // Loop over each config of this table and callback cryptor extension point handler
        foreach($config as $eventType => $fieldnames) {
            $className = 'cryptor_yform_ep_' . strtolower($ep->getName());
            if ($ep->getName() === $eventType && class_exists($className)) {
                call_user_func([$className, 'execute'], $ep, $fieldnames);
            }
        }
    }
    
    /**
     * Handles ajax request
     * @param type $type
     * @param type $params
     * @return type
     */
    public static function handleAjaxRequest($type, $params) {
        if ($type === 'backend_decrypt') {
            return json_encode(cryptor::decrypt($params));
        }
        
        else if ($type === 'backend_encrypt') {
            return json_encode(cryptor::encrypt($params));
        }
        
        else if ($type === 'field_names') {
            $yFormTable = rex_yform_manager_table::get($params);
            $config = self::getConfigForTable($params);
            $fields = self::getEncyptedFieldLabels($config, $yFormTable);
            return json_encode($fields);
        }
    }

    /**
     * Returns the config for a table
     * @param <string> $tablename
     * @return <mixed> $configArray || false
     */
    private static function getConfigForTable($tablename) {
        return rex_plugin::get('cryptor', 'yform')->getConfig($tablename);
    }
    
    private static function getEncyptedFieldLabels($config, $yFormTable) {
        $fields = [];
        foreach($config as $extensionPoint) {
            if (!is_array($extensionPoint)) {
                continue;
            }
            foreach($extensionPoint as $fieldname => $status) {
                if ($status !== 'on') {
                    continue;
                }
                $fields[] = [
                    'name' => $fieldname,
                    'label' => $yFormTable->getValueField($fieldname)->getLabel()
                ];
            }
        }
        return $fields;
    }
    
    private static function isEncryptedField() {
        
    } 
}
