<?php

/**
 * cryptor/yform
 *
 * @author marcel@scherkamp.de
 * @package cryptor
 */
$fieldDbTypes = ['text', 'textarea', 'email'];
$extensionPoints = $this->getConfig('extension_points');
$tableName = rex_get('table_name', 'string', null);

// Save config
if (rex_post('fields-submit', 'string') !== '' && rex::getUser()->hasPerm('cryptor[yform]')) {
    $this->setConfig($tableName, rex_post('cryptor', [$extensionPoints]));
    $messages[] = $this->i18n('message_config_saved_successful');
}

// Get config
$config = $this->getConfig($tableName);

// Table header
$content = '<table class="table"><thead>';
$content .= '<tr><th>' . $this->i18n('yform_label_fieldname') . '</th>';
$content .= '<th>' . $this->i18n('yform_label_fieldlabel') . '</th>';
$content .= '<th>' . $this->i18n('yform_label_fieldtype') . '</th>';
$content .= '<th>' . $this->i18n('yform_label_encrypt_on_extension_point') . '</th>';
$content .= '</tr></thead>';

// Fetch table and fields
$table = rex_yform_manager_table::get($tableName);
if ($table) {
    $fields = $table->getValueFields();
    
    // Loop over each field and show settings
    foreach($fields as $field) {
        
        // Limit field to supported dbtypes
        if (in_array($field->getTypeName(), $fieldDbTypes) !== true) {
            continue;
        }
        
        // Create table row
        $content .= '<tr><td>' . $field->getName() . '</td>';
        $content .= '<td>' . $field->getLabel() . '</td>';
        $content .= '<td>' . $field->getTypeName() . '</td>';
        
        // Checkbox encrypt on extension point
        foreach($extensionPoints as $epName) {
            $checked = (isset($config[$epName][$field->getName()]) && $config[$epName][$field->getName()] === 'on');
            $content .= '<td><label><input type="checkbox" name="cryptor[' . $epName . '][' . $field->getName() . ']"';
            $content .= (($checked === true) ? 'checked' : '') . '> ' . $epName. '</label></td>';  
        }
        $content .= '</tr>';
    }
}

// Close table add notes
$content .= '</table>';
$content .= '<p class="help-block rex-note"><strong>' . rex_i18n::msg('cryptor_yform_note_ep_legend') . ':</strong><br>';
foreach($extensionPoints as $epName) {
    $content .= $this->i18n('yform_note_ep_' . strtolower($epName), $epName)  . '<br>';
}
$content .= '</p>';

// Submit button
$formElements = [];
$field  = '<button class="btn btn-save rex-form-aligned" type="submit" name="fields-submit" value="1" ';
$field .= ' onclick="return confirm(\'' . $this->i18n('yform_fields_confirm_change') . '\')" ';
$field .= rex::getAccesskey($this->i18n('button_save'), 'save') . '>';
$field .= $this->i18n('button_save') . '</button>';
$formElements[] = ['field' => $field];

// Submit button fragment
$fragment = new rex_fragment();
$fragment->setVar('flush', true);
$fragment->setVar('elements', $formElements, false);
$buttons = $fragment->parse('core/form/submit.php');

// Build page
$fragment = new rex_fragment();
$fragment->setVar('class', 'edit');
$fragment->setVar('title', $this->i18n('yform_fields_title', $table->getName()) . '');
$fragment->setVar('body', $content, false);
$fragment->setVar('buttons', $buttons, false);
$out = $fragment->parse('core/page/section.php');

echo '<form action="' . rex_url::currentBackendPage(['table_name' => $tableName]) . '" method="post">' . $out . '</form>';